betty.locale.error module - Betty documentation

Hide navigation sidebar
Hide table of contents sidebar
Skip to content
Back to top
View this page
Toggle table of contents sidebar

# betty.locale.error module

Provide Locale API errors.

exception betty.locale.error.InvalidLocale

  Bases: `LocaleError`, `ValueError`

  Raised when a value is not a valid locale.

  __init__(invalid_locale: str) → None

exception betty.locale.error.LocaleError

  Bases: `UserFacingError`, `Exception`

  A locale API error.

exception betty.locale.error.LocaleNotFound

  Bases: `LocaleError`, `ValueError`

  Raised when a locale could not be found.

  __init__(locale: str) → None